Index: test/edu/ucsb/nceas/metacatnettest/MetaCatServletNetTest.java
===================================================================
--- test/edu/ucsb/nceas/metacatnettest/MetaCatServletNetTest.java	(revision 4211)
+++ test/edu/ucsb/nceas/metacatnettest/MetaCatServletNetTest.java	(revision 4212)
@@ -178,8 +178,8 @@
 	 * Test insert a xml document successfully
 	 */
 	public void testInsertXMLDocument() throws PropertyNotFoundException {
-		String name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "1";
+		String name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "1";
 		logMetacat.info("insert docid: " + name);
 		String content = "<?xml version=\"1.0\"?>"
 				+ "<!DOCTYPE acl PUBLIC \"-//ecoinformatics.org//"
@@ -201,8 +201,8 @@
 	 * In the String, there is no <!Doctype ... Public/System/>
 	 */
 	public void testInsertInvalidateXMLDocument() throws PropertyNotFoundException  {
-		String name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "1";
+		String name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "1";
 		logMetacat.info("insert docid: " + name);
 		String content = "<?xml version=\"1.0\"?>"
 				+ "<acl authSystem=\"knb\" order=\"allowFirst\">" + "<identifier>" + name
@@ -220,8 +220,8 @@
 	 * There is no </acl> in this string
 	 */
 	public void testInsertNonWellFormedXMLDocument() throws PropertyNotFoundException  {
-		String name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "1";
+		String name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "1";
 		logMetacat.info("insert non well-formed docid: " + name);
 		String content = "<?xml version=\"1.0\"?>"
 				+ "<acl authSystem=\"knb\" order=\"allowFirst\">" + "<identifier>" + name
@@ -239,8 +239,8 @@
 	 * Test read a xml document  in xml format successfully
 	 */
 	public void testReadXMLDocumentXMLFormat() throws PropertyNotFoundException  {
-		String name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "1";
+		String name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "1";
 		assertTrue(handleReadAction(name, "xml"));
 
 	}
@@ -249,8 +249,8 @@
 	 * Test read a xml document  in html format successfully
 	 */
 	public void testReadXMLDocumentHTMLFormat() throws PropertyNotFoundException {
-		String name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "1";
+		String name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "1";
 		assertTrue(handleReadAction(name, "html"));
 
 	}
@@ -259,8 +259,8 @@
 	 * Test read a xml document  in zip format successfully
 	 */
 	public void testReadXMLDocumentZipFormat() throws PropertyNotFoundException {
-		String name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "1";
+		String name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "1";
 		assertTrue(handleReadAction(name, "zip"));
 
 	}
@@ -269,8 +269,8 @@
 	 * Test insert a xml document successfully
 	 */
 	public void testUpdateXMLDocument() throws PropertyNotFoundException {
-		String name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "2";
+		String name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "2";
 		logMetacat.info("update docid: " + name);
 		String content = "<?xml version=\"1.0\"?>"
 				+ "<!DOCTYPE acl PUBLIC \"-//ecoinformatics.org//"
@@ -291,8 +291,8 @@
 	 * Test insert a data file successfully
 	 */
 	public void testInertDataFile() throws PropertyNotFoundException {
-		String name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "1";
+		String name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "1";
 		logMetacat.info("insert data file docid: " + name);
 		logMetacat.info("insert data file ");
 		File hello = new File("test/jones.204.22.xml");
@@ -304,8 +304,8 @@
 	 * Test delete a xml document successfully
 	 */
 	public void testDeleteXMLDocument() throws PropertyNotFoundException {
-		String name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "2";
+		String name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "2";
 		logMetacat.info("delete docid: " + name);
 		assertTrue(handleDeleteFile(name));
 
Index: test/edu/ucsb/nceas/metacattest/QuerySpecificationTest.java
===================================================================
--- test/edu/ucsb/nceas/metacattest/QuerySpecificationTest.java	(revision 4211)
+++ test/edu/ucsb/nceas/metacattest/QuerySpecificationTest.java	(revision 4212)
@@ -149,7 +149,7 @@
             System.out.println("---- SQL ------------------");
             QuerySpecification qspec = new QuerySpecification(xml, 
                     PropertyService.getProperty("saxparser"), 
-                    PropertyService.getProperty("accNumSeparator"));
+                    PropertyService.getProperty("document.accNumSeparator"));
             String query = qspec.printSQL(false);
            assertTrue(selectionQuery.equals(query.trim()));
         } catch (IOException e) {
@@ -168,7 +168,7 @@
             System.out.println("---- orginal EXT SQL  ------------------\n"+extendedQuery);
             QuerySpecification qspec = new QuerySpecification(xml, 
                     PropertyService.getProperty("saxparser"), 
-                    PropertyService.getProperty("accNumSeparator"));
+                    PropertyService.getProperty("document.accNumSeparator"));
             String query = 
                     qspec.printExtendedSQL(
                             "'obfs.45337', 'obfs.45338', 'obfs.45346'", true);
Index: test/edu/ucsb/nceas/metacattest/QueryResultBuilderTest.java
===================================================================
--- test/edu/ucsb/nceas/metacattest/QueryResultBuilderTest.java	(revision 4211)
+++ test/edu/ucsb/nceas/metacattest/QueryResultBuilderTest.java	(revision 4212)
@@ -233,7 +233,7 @@
         	String   createDate = result.getString(5);
         	String updateDate = result.getString(6);
         	String completeDocid = docid
-                             + PropertyService.getProperty("accNumSeparator");
+                             + PropertyService.getProperty("document.accNumSeparator");
             completeDocid += rev;
             // Put everything into a string buffer
             StringBuffer document = new StringBuffer();
Index: test/edu/ucsb/nceas/metacattest/MetaCatServletTest.java
===================================================================
--- test/edu/ucsb/nceas/metacattest/MetaCatServletTest.java	(revision 4211)
+++ test/edu/ucsb/nceas/metacattest/MetaCatServletTest.java	(revision 4212)
@@ -224,8 +224,8 @@
 	public void testInsertXMLDocument() {
 		String name = null;
 		try {
-			name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-					+ PropertyService.getProperty("accNumSeparator") + "1";
+			name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+					+ PropertyService.getProperty("document.accNumSeparator") + "1";
 		} catch (PropertyNotFoundException pnfe) {
 			fail("Could not find property: " + pnfe.getMessage());
 		}
@@ -252,8 +252,8 @@
 	public void testInsertInvalidateXMLDocument() {
 		String name = null;
 		try {
-			name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "1";
+			name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "1";
 		} catch (PropertyNotFoundException pnfe) {
 			fail("Could not find property: " + pnfe.getMessage());
 		}
@@ -276,8 +276,8 @@
 	public void testInsertNonWellFormedXMLDocument() {
 		String name = null;
 		try {
-			name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "1";
+			name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "1";
 		} catch (PropertyNotFoundException pnfe) {
 			fail("Could not find property: " + pnfe.getMessage());
 		}
@@ -300,8 +300,8 @@
 	public void testReadXMLDocumentXMLFormat() {
 		String name = null;
 		try {
-			name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "1";
+			name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "1";
 		} catch (PropertyNotFoundException pnfe) {
 			fail("Could not find property: " + pnfe.getMessage());
 		}
@@ -315,8 +315,8 @@
 	public void testReadXMLDocumentHTMLFormat() {
 		String name = null;
 		try {
-			name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "1";
+			name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "1";
 		} catch (PropertyNotFoundException pnfe) {
 			fail("Could not find property: " + pnfe.getMessage());
 		}	
@@ -330,8 +330,8 @@
 	public void testReadXMLDocumentZipFormat() {
 		String name = null;
 		try {
-			name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "1";
+			name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "1";
 		} catch (PropertyNotFoundException pnfe) {
 			fail("Could not find property: " + pnfe.getMessage());
 		}	
@@ -345,8 +345,8 @@
 	public void testUpdateXMLDocument() {
 		String name = null;
 		try {
-			name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "2";
+			name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "2";
 		} catch (PropertyNotFoundException pnfe) {
 			fail("Could not find property: " + pnfe.getMessage());
 		}		
@@ -372,8 +372,8 @@
 	public void testDeleteXMLDocument() {
 		String name = null;
 		try {
-			name = "john" + PropertyService.getProperty("accNumSeparator") + serialNumber
-				+ PropertyService.getProperty("accNumSeparator") + "2";
+			name = "john" + PropertyService.getProperty("document.accNumSeparator") + serialNumber
+				+ PropertyService.getProperty("document.accNumSeparator") + "2";
 		} catch (PropertyNotFoundException pnfe) {
 			fail("Could not find property: " + pnfe.getMessage());
 		}
Index: src/edu/ucsb/nceas/metacat/MetaCatServlet.java
===================================================================
--- src/edu/ucsb/nceas/metacat/MetaCatServlet.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/MetaCatServlet.java	(revision 4212)
@@ -221,13 +221,13 @@
 			// schema, which accidentily points to wrong version of
 			// eml-resource.xsd.
 			String correctedEML201Doc = PropertyService
-					.getProperty("eml201_document_corrected");
+					.getProperty("document.eml201DocumentCorrected");
 			if (correctedEML201Doc != null && correctedEML201Doc.equals(FALSE)) {
 				logMetacat.info("===Start to correct eml201 documents");
 				EML201DocumentCorrector correct = new EML201DocumentCorrector();
 				boolean success = correct.run();
 				if (success) {
-					PropertyService.setProperty("eml201_document_corrected", TRUE);
+					PropertyService.setProperty("document.eml201DocumentCorrected", TRUE);
 				}
 				logMetacat.info("====Finish to correct eml201 documents");
 			}
@@ -3654,7 +3654,7 @@
     private static String appendRev(String docid) throws Exception {
         Logger logMetacat = Logger.getLogger(MetaCatServlet.class);
         String newAccNum = null;
-        String separator = PropertyService.getProperty("accNumSeparator");
+        String separator = PropertyService.getProperty("document.accNumSeparator");
         int firstIndex = docid.indexOf(separator);
         int lastIndex = docid.lastIndexOf(separator);
         if (firstIndex == lastIndex) {
Index: src/edu/ucsb/nceas/metacat/ContentTypeProvider.java
===================================================================
--- src/edu/ucsb/nceas/metacat/ContentTypeProvider.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/ContentTypeProvider.java	(revision 4212)
@@ -185,7 +185,7 @@
     // create xml document
     try
     {
-      String accNumber = eml2DocId + PropertyService.getProperty("accNumSeparator") +
+      String accNumber = eml2DocId + PropertyService.getProperty("document.accNumSeparator") +
                     DBUtil.getLatestRevisionInDocumentTable(eml2DocId);
       //System.out.println("the acc number is !!!!!!!!!!!!!!!!!"+accNumber);
       xmlDoc = new DocumentImpl(accNumber);
@@ -555,7 +555,7 @@
     String xmlDoc = null;
     try
     {
-      String accNumber = physicalDocid + PropertyService.getProperty("accNumSeparator") +
+      String accNumber = physicalDocid + PropertyService.getProperty("document.accNumSeparator") +
         DBUtil.getLatestRevisionInDocumentTable(physicalDocid);
       //System.out.println("the accenumber is !!!!!!!!!!!!!!!!!!" + accNumber);
       DocumentImpl doc = new DocumentImpl(accNumber);
Index: src/edu/ucsb/nceas/metacat/DocumentImpl.java
===================================================================
--- src/edu/ucsb/nceas/metacat/DocumentImpl.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/DocumentImpl.java	(revision 4212)
@@ -2038,7 +2038,7 @@
                 int thisrev = DBUtil.getLatestRevisionInDocumentTable(docid);
                 logMetacat.info("this revsion is: " + thisrev);
                 // Save the old document publicaccessentry in a backup table
-                String accNumber = docid+PropertyService.getProperty("accNumSeparator")+thisrev;
+                String accNumber = docid+PropertyService.getProperty("document.accNumSeparator")+thisrev;
                 thisdoc = new DocumentImpl(accNumber, false);
                 DocumentImpl.archiveDocAndNodesRevision(connection, docid, user, thisdoc);
                 logMetacat.info("after archiveDoc");
@@ -2426,7 +2426,7 @@
         ForceReplicationHandler frh = new ForceReplicationHandler(accnum,
                 action, true, null);
         // clear cache after inserting or updating a document
-        if (PropertyService.getProperty("query_cache_on").equals("true"))
+        if (PropertyService.getProperty("database.queryCacheOn").equals("true"))
         {
           //System.out.println("the string stored into cache is "+ resultsetBuffer.toString());
      	   DBQuery.clearQueryResultCache();
@@ -2613,7 +2613,7 @@
         }
         
         // clear cache after inserting or updating a document
-        if (PropertyService.getProperty("query_cache_on").equals("true"))
+        if (PropertyService.getProperty("database.queryCacheOn").equals("true"))
         {
           //System.out.println("the string stored into cache is "+ resultsetBuffer.toString());
      	   DBQuery.clearQueryResultCache();
@@ -2926,7 +2926,7 @@
             ForceReplicationHandler frh = new ForceReplicationHandler(
                              accnum, ForceReplicationHandler.DELETE, isXML, notifyServer);
             // clear cache after inserting or updating a document
-            if (PropertyService.getProperty("query_cache_on").equals("true"))
+            if (PropertyService.getProperty("database.queryCacheOn").equals("true"))
             {
               //System.out.println("the string stored into cache is "+ resultsetBuffer.toString());
          	   DBQuery.clearQueryResultCache();
@@ -3158,7 +3158,7 @@
 
         try {
             if (doc == null) {
-                String accNumber = docid + PropertyService.getProperty("accNumSeparator") +
+                String accNumber = docid + PropertyService.getProperty("document.accNumSeparator") +
                 DBUtil.getLatestRevisionInDocumentTable(docid);
                     doc = new DocumentImpl(accNumber);
             }
Index: src/edu/ucsb/nceas/metacat/ReplicationHandler.java
===================================================================
--- src/edu/ucsb/nceas/metacat/ReplicationHandler.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/ReplicationHandler.java	(revision 4212)
@@ -331,7 +331,7 @@
       String createdDate = (String)docinfoHash.get("date_created");
       String updatedDate = (String)docinfoHash.get("date_updated");
       //docid should include rev number too
-      /*String accnum=docId+util.getProperty("accNumSeparator")+
+      /*String accnum=docId+util.getProperty("document.accNumSeparator")+
                                               (String)docinfoHash.get("rev");*/
       logMetacat.info("docid in repl: "+accNumber);
       String docType = (String)docinfoHash.get("doctype");
@@ -454,7 +454,7 @@
       String createdDate = (String)docinfoHash.get("date_created");
       String updatedDate = (String)docinfoHash.get("date_updated");
       //docid should include rev number too
-      /*String accnum=docId+util.getProperty("accNumSeparator")+
+      /*String accnum=docId+util.getProperty("document.accNumSeparator")+
                                               (String)docinfoHash.get("rev");*/
 
 
@@ -558,7 +558,7 @@
 
          //because delete method docid should have rev number
          //so we just add one for it. This rev number is no sence.
-         String accnum=docId+PropertyService.getProperty("accNumSeparator")+"1";
+         String accnum=docId+PropertyService.getProperty("document.accNumSeparator")+"1";
          //System.out.println("accnum: "+accnum);
          DocumentImpl.delete(accnum, null, null, notifyServer);
          logMetacat.info("Successfully deleted doc " + docId);
@@ -1112,7 +1112,7 @@
          }
        }
        
-       String accNumber = docid + PropertyService.getProperty("accNumSeparator") + rev;
+       String accNumber = docid + PropertyService.getProperty("document.accNumSeparator") + rev;
        // this is non-data file
        if(flag && !dataFile)
        {
@@ -1178,7 +1178,7 @@
            flag = true;    
        }
      
-       String accNumber = docid + PropertyService.getProperty("accNumSeparator") + rev;
+       String accNumber = docid + PropertyService.getProperty("document.accNumSeparator") + rev;
        // this is non-data file
        if(flag && !dataFile)
        {
Index: src/edu/ucsb/nceas/metacat/RelationHandler.java
===================================================================
--- src/edu/ucsb/nceas/metacat/RelationHandler.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/RelationHandler.java	(revision 4212)
@@ -219,7 +219,7 @@
 				rev = rs.getInt(2);
 				String sep = ".";
 				try {
-					sep = PropertyService.getProperty("accNumSeparator");
+					sep = PropertyService.getProperty("document.accNumSeparator");
 				} catch (PropertyNotFoundException pnfe) {
 					logMetacat.error("Could not find account separator.  Setting to '.': " + pnfe.getMessage());
 				}
Index: src/edu/ucsb/nceas/metacat/AccessionNumber.java
===================================================================
--- src/edu/ucsb/nceas/metacat/AccessionNumber.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/AccessionNumber.java	(revision 4212)
@@ -58,8 +58,8 @@
 	 */
 	private AccessionNumber() throws AccessionNumberException {
 		try {
-			this.sitecode = PropertyService.getProperty("sitecode");
-			this.sep = PropertyService.getProperty("accNumSeparator");
+			this.sitecode = PropertyService.getProperty("document.sitecode");
+			this.sep = PropertyService.getProperty("document.accNumSeparator");
 		} catch (PropertyNotFoundException pnfe) {
 			throw new AccessionNumberException("Could not retrieve property "
 					+ "in constructor: " + pnfe.getMessage());
Index: src/edu/ucsb/nceas/metacat/DBUtil.java
===================================================================
--- src/edu/ucsb/nceas/metacat/DBUtil.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/DBUtil.java	(revision 4212)
@@ -347,7 +347,7 @@
     String accnum = null;
     String sep = ".";
     try {
-    	PropertyService.getProperty("accNumSeparator");
+    	PropertyService.getProperty("document.accNumSeparator");
     } catch (PropertyNotFoundException pnfe) {
     	logMetacat.error("could not get property 'accNumSeparator'.  setting to '.': " 
     			+ pnfe.getMessage());  	
@@ -446,7 +446,7 @@
     String accnum = null;
     String sep = ".";
     try {
-    	PropertyService.getProperty("accNumSeparator");
+    	PropertyService.getProperty("document.accNumSeparator");
     } catch (PropertyNotFoundException pnfe) {
     	logMetacat.error("could not get property 'accNumSeparator'.  setting to '.': " 
     			+ pnfe.getMessage());  	
Index: src/edu/ucsb/nceas/metacat/Sitemap.java
===================================================================
--- src/edu/ucsb/nceas/metacat/Sitemap.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/Sitemap.java	(revision 4212)
@@ -143,7 +143,7 @@
                         writeSitemapHeader(sitemap);
                     }
 
-                    String separator = PropertyService.getProperty("accNumSeparator");
+                    String separator = PropertyService.getProperty("document.accNumSeparator");
                     String docid = rs.getString(1) + separator
                             + rs.getString(2);
                     writeSitemapEntry(sitemap, docid);
Index: src/edu/ucsb/nceas/metacat/Eml200SAXHandler.java
===================================================================
--- src/edu/ucsb/nceas/metacat/Eml200SAXHandler.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/Eml200SAXHandler.java	(revision 4212)
@@ -313,7 +313,7 @@
         try
         {
             PermissionController control = new PermissionController(docid
-                    + PropertyService.getProperty("accNumSeparator") + revision);
+                    + PropertyService.getProperty("document.accNumSeparator") + revision);
             //unChangableSubTreeHash = getUnchangableSubTree(control, user,
             // groups);
 
@@ -601,7 +601,7 @@
                 String docidWithoutRev = MetaCatUtil.getDocIdFromString(docid);
                 String seperator = ".";
                 try {
-					seperator = PropertyService.getProperty("accNumSeparator");
+					seperator = PropertyService.getProperty("document.accNumSeparator");
 				} catch (PropertyNotFoundException pnfe) {
 					logMetacat.error("Could not get property 'accNumSeparator'.  " 
 							+ "Setting separator to '.': "+ pnfe.getMessage());
Index: src/edu/ucsb/nceas/metacat/Eml210SAXHandler.java
===================================================================
--- src/edu/ucsb/nceas/metacat/Eml210SAXHandler.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/Eml210SAXHandler.java	(revision 4212)
@@ -196,7 +196,7 @@
         // Get the unchangable subtrees (user doesn't have write permission)
         try {
             PermissionController control = new PermissionController(docid
-                    + PropertyService.getProperty("accNumSeparator") + revision);
+                    + PropertyService.getProperty("document.accNumSeparator") + revision);
             //unChangableSubTreeHash = getUnchangableSubTree(control, user,
             // groups);
 
@@ -347,7 +347,7 @@
                 String docidWithoutRev = MetaCatUtil.getDocIdFromString(docid);
                 String seperator = ".";
                 try {
-                seperator = PropertyService.getProperty("accNumSeparator");
+                seperator = PropertyService.getProperty("document.accNumSeparator");
                 } catch (PropertyNotFoundException pnfe) {
                 	logMetacat.error("Could not fing property 'accNumSeparator'. " 
                 			+ "Setting separator to '.': " + pnfe.getMessage());
Index: src/edu/ucsb/nceas/metacat/DocumentIdentifier.java
===================================================================
--- src/edu/ucsb/nceas/metacat/DocumentIdentifier.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/DocumentIdentifier.java	(revision 4212)
@@ -52,7 +52,7 @@
 	public DocumentIdentifier(String docid) throws AccessionNumberException {
 		this.docid = docid;
 		try {
-			this.separator = PropertyService.getProperty("accNumSeparator");
+			this.separator = PropertyService.getProperty("document.accNumSeparator");
 		} catch (PropertyNotFoundException pnfe) {
 			throw new AccessionNumberException(
 					"Could not get property 'accNumSeparator' :" + pnfe.getMessage());
Index: src/edu/ucsb/nceas/metacat/RemoteDocument.java
===================================================================
--- src/edu/ucsb/nceas/metacat/RemoteDocument.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/RemoteDocument.java	(revision 4212)
@@ -92,7 +92,7 @@
     userName = myUserName;
     passWord = myPassWord;
     zipEntry = myZipEntryPath+ docIdWithoutRevision + 
-                PropertyService.getProperty("accNumSeparator") + revision;
+                PropertyService.getProperty("document.accNumSeparator") + revision;
    
 
   }// Constructor
@@ -207,7 +207,7 @@
       throw new Exception ("Couldn't find a dataset docid for the required id");
     }
     // Create a documentImpl object
-    String accNumber = givenDocId + PropertyService.getProperty("accNumSeparator") +
+    String accNumber = givenDocId + PropertyService.getProperty("document.accNumSeparator") +
     DBUtil.getLatestRevisionInDocumentTable(givenDocId);
     document = new DocumentImpl(accNumber, false);
     // get the replication home server (it come from xml_replication table)
@@ -295,7 +295,7 @@
     }
     // User specified docid (including revision number
     String specifiedDocId = docIdWithoutRevision + 
-                PropertyService.getProperty("accNumSeparator") +revision;
+                PropertyService.getProperty("document.accNumSeparator") +revision;
     logMetacat.info("The requried docid is: "+ specifiedDocId);
     
     // At first login to remote metacat server. 
@@ -366,7 +366,7 @@
     }
     // User specified docid (including revision number
     String specifiedDocId = docIdWithoutRevision + 
-                PropertyService.getProperty("accNumSeparator") +revision;
+                PropertyService.getProperty("document.accNumSeparator") +revision;
     logMetacat.info("The requried docid is: "+ specifiedDocId);
     
     // At first login to remote metacat server.
Index: src/edu/ucsb/nceas/metacat/AccessControlList.java
===================================================================
--- src/edu/ucsb/nceas/metacat/AccessControlList.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/AccessControlList.java	(revision 4212)
@@ -131,7 +131,7 @@
   {
 		String parserName = PropertyService.getProperty("saxparser");
 		this.server = SystemUtil.getSecureServerURL();
-		this.sep = PropertyService.getProperty("accNumSeparator");
+		this.sep = PropertyService.getProperty("document.accNumSeparator");
 
 		this.connection = conn;
 		this.parserName = parserName;

Index: src/edu/ucsb/nceas/metacat/util/MetaCatUtil.java
===================================================================
--- src/edu/ucsb/nceas/metacat/util/MetaCatUtil.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/util/MetaCatUtil.java	(revision 4212)
@@ -81,7 +81,7 @@
         }
 
         try {
-        	separator = PropertyService.getProperty("accNumSeparator").charAt(0);
+        	separator = PropertyService.getProperty("document.accNumSeparator").charAt(0);
         } catch (PropertyNotFoundException pnfe) {
         	logMetacat.error("Could not retrieve account number separator. " 
         			+ "Separator set to '.' : " + pnfe.getMessage());
@@ -722,8 +722,8 @@
 
     /**
 	 * Writes debug information into a file. In metacat.properties, if property
 	 * writeDebugToFile is set to true, the debug information will be written to
 	 * debug file, which value is the property debugOutputFile in
 	 * metacat.properties.
 	 * 
 	 */
@@ -730,10 +730,10 @@
 	public static void writeDebugToFile(String debugInfo) {
 		String debug = "false";
 		try {
-			debug = PropertyService.getProperty("writeDebugToFile");
+			debug = PropertyService.getProperty("application.writeDebugToFile");
 			if (debug != null && debug.equalsIgnoreCase("true")) {
 				File outputFile = 
-					new File(PropertyService.getProperty("debugOutputFile"));
+					new File(PropertyService.getProperty("application.debugOutputFile"));
 				FileOutputStream fos = new FileOutputStream(outputFile, true);
 				PrintWriter pw = new PrintWriter(fos);
 				pw.println(debugInfo);
@@ -765,10 +765,10 @@
 	public static void writeDebugToDelimiteredFile(String debugInfo, boolean newLine) {
 		String debug = "false";
 		try {
-			debug = PropertyService.getProperty("writeDebugToFile");
+			debug = PropertyService.getProperty("application.writeDebugToFile");
 			if (debug != null && debug.equalsIgnoreCase("true")) {
 				File outputFile = new File(PropertyService
-						.getProperty("delimiteredOutputFile"));
+						.getProperty("application.delimiteredOutputFile"));
 				FileOutputStream fos = new FileOutputStream(outputFile, true);
 				PrintWriter pw = new PrintWriter(fos);
 				if (newLine) {
@@ -722,8 +722,8 @@
     /**
 	 * Writes debug information into a file. In metacat.properties, if property
-	 * writeDebugToFile is set to true, the debug information will be written to
-	 * debug file, which value is the property debugOutputFile in
+	 * application.writeDebugToFile is set to true, the debug information will be written to
+	 * debug file, which value is the property application.debugOutputFile in
 	 * metacat.properties.
 	 * 
Index: src/edu/ucsb/nceas/metacat/DBQuery.java
===================================================================
--- src/edu/ucsb/nceas/metacat/DBQuery.java	(revision 4211)
+++ src/edu/ucsb/nceas/metacat/DBQuery.java	(revision 4212)
@@ -92,7 +92,7 @@
     static {
     	int qryRsltCacheSize = 0;
     	try {
-    		qryRsltCacheSize = Integer.parseInt(PropertyService.getProperty("queryresult_cache_size"));
+    		qryRsltCacheSize = Integer.parseInt(PropertyService.getProperty("database.queryresultCacheSize"));
     	} catch (PropertyNotFoundException pnfe) {
     		System.err.println("Could not get QUERYRESULTCACHESIZE property in static block: "
 					+ pnfe.getMessage());
@@ -234,7 +234,7 @@
     {
     	// since the query will be too long to be handled, so we divided the 
     	// docids vector into couple vectors.
-    	int size = (new Integer(PropertyService.getProperty("app_resultsetsize"))).intValue();
+    	int size = (new Integer(PropertyService.getProperty("database.appResultsetSize"))).intValue();
     	logMetacat.info("The size of select doicds is "+docids.size());
     	logMetacat.info("The application result size in metacat.properties is "+size);
     	Vector subset = new Vector();
@@ -347,7 +347,7 @@
          {
            qspec = new QuerySpecification(xmlquery,
                                           parserName,
-                                          PropertyService.getProperty("accNumSeparator"));
+                                          PropertyService.getProperty("document.accNumSeparator"));
          }
          catch (Exception ee)
          {
@@ -573,12 +573,12 @@
       {
         // for html page, we put everything into one page
         offset =
-            (new Integer(PropertyService.getProperty("web_resultsetsize"))).intValue();
+            (new Integer(PropertyService.getProperty("database.webResultsetSize"))).intValue();
       }
       else
       {
           offset =
-              (new Integer(PropertyService.getProperty("app_resultsetsize"))).intValue();
+              (new Integer(PropertyService.getProperty("database.appResultsetSize"))).intValue();
       }
 
       /*
@@ -625,7 +625,7 @@
       String selectionAndExtendedQuery = null;
       // we only get cache for public
       if (user != null && user.equalsIgnoreCase("public") 
-     		 && pagesize == 0 && PropertyService.getProperty("query_cache_on").equals("true"))
+     		 && pagesize == 0 && PropertyService.getProperty("database.queryCacheOn").equals("true"))
       {
     	  selectionAndExtendedQuery = query +qspec.getReturnDocList()+qspec.getReturnFieldList();
    	      String cachedResult = getResultXMLFromCache(selectionAndExtendedQuery);
@@ -682,7 +682,7 @@
            document = new StringBuffer();
 
            String completeDocid = docid
-                            + PropertyService.getProperty("accNumSeparator");
+                            + PropertyService.getProperty("document.accNumSeparator");
            completeDocid += rev;
            document.append("<docid>").append(completeDocid).append("</docid>");
            if (docname != null)
@@ -780,7 +780,7 @@
      
      // now we only cached none-paged query and user is public
      if (user != null && user.equalsIgnoreCase("public") 
-    		 && pagesize == NONPAGESIZE && PropertyService.getProperty("query_cache_on").equals("true"))
+    		 && pagesize == NONPAGESIZE && PropertyService.getProperty("database.queryCacheOn").equals("true"))
      {
        //System.out.println("the string stored into cache is "+ resultsetBuffer.toString());
   	   storeQueryResultIntoCache(selectionAndExtendedQuery, resultsetBuffer.toString());
@@ -807,9 +807,9 @@
      int usage_count = getXmlReturnfieldsTableId(qspec, dbconn);
      boolean enterRecords = false;
 
      // get value of xml_returnfield_count
      int count = (new Integer(PropertyService
-                            .getProperty("xml_returnfield_count")))
+                            .getProperty("database.xmlReturnfieldCount")))
                             .intValue();
 
      // set enterRecords to true if usage_count is more than the offset
@@ -877,7 +877,7 @@
      String element = null;
      String query = null;
      int offset = (new Integer(PropertyService
-                               .getProperty("queryresult_string_length")))
+                               .getProperty("database.queryresultStringLength")))
                                .intValue();
      while (keys.hasNext())
      {
@@ -1996,7 +1996,7 @@
                 }
 
                 String docidPlusVersion = ((String) docIdList.elementAt(i))
-                        + PropertyService.getProperty("accNumSeparator") + rev;
+                        + PropertyService.getProperty("document.accNumSeparator") + rev;
 
                 //create new documentImpl object
                 DocumentImpl documentImplObject = new DocumentImpl(
@@ -2273,8 +2273,8 @@
                 version = currentVersion;
                 //get package zip entry name
                 //it should be docId.revsion.package
-                rootName = packageId + PropertyService.getProperty("accNumSeparator")
-                        + version + PropertyService.getProperty("accNumSeparator")
+                rootName = packageId + PropertyService.getProperty("document.accNumSeparator")
+                        + version + PropertyService.getProperty("document.accNumSeparator")
                         + "package";
                 //get the whole id list for data packadge
                 docIdList = getCurrentDocidListForDataPackage(packageId);
@@ -2290,7 +2290,7 @@
             {
 
                 rootName = docIdString
-                        + PropertyService.getProperty("accNumSeparator") + "package";
+                        + PropertyService.getProperty("document.accNumSeparator") + "package";
                 //get the whole id list for data packadge
                 docIdList = getOldVersionDocidListForDataPackage(docIdString);
 
@@ -2338,7 +2338,7 @@
                             // Add String object to htmlDocumentImplList
                             String elementInHtmlList = remoteDoc
                                     .getDocIdWithoutRevsion()
-                                    + PropertyService.getProperty("accNumSeparator")
+                                    + PropertyService.getProperty("document.accNumSeparator")
                                     + remoteDoc.getRevision();
                             htmlDocumentImplList.add(elementInHtmlList);
                         }//if
@@ -807,9 +807,9 @@
      boolean enterRecords = false;
 
-     // get value of xml_returnfield_count
+     // get value of database.xmlReturnfieldCount
      int count = (new Integer(PropertyService